@@ -6,6 +6,12 @@ def open_output(ofile, mode='wt'):
         with open('/dev/stdout', mode=mode) as out:
             yield out
     else:
-        from atomicwrites import atomic_write
+        try:
+            from atomicwrites import atomic_write
+        except ImportError:
+            with open(ofile, mode=mode) as out:
+                yield out
+            return
+
         with atomic_write(ofile, mode=mode, overwrite=True) as out:
             yield out
